@@ -5,7 +5,11 @@ Simplified email sending in Python.
 """
 
 __title__ = 'mailclient'
-__version__ = '0.1.1'
+__version__ = '0.2.0'
 __author__ = 'Adrian Espinosa'
 __license__ = 'Apache 2.0'
-__copyright__ = 'Copyright 2013 Adrian Espinosa'
\ No newline at end of file
+__copyright__ = 'Copyright 2013 Adrian Espinosa'
+
+
+from .message import Message
+from .server import Server
\ No newline at end of file
